/*
 * Copyright (c) 1999 Richard Seaman, Jr.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by Richard Seaman, Jr.
 * 4. Neither the name of the author nor the names of any co-contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY RICHARD SEAMAN, Jr. AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#ifndef PTHREAD_STACK_H
#define PTHREAD_STACK_H

#include <vm/vm.h>
#include <vm/pmap.h>
#include <machine/pmap.h>
#include <machine/vmparam.h>
#include <machine/param.h>

/*
 * The stackaddr functions are implemented here with special restrictions,
 * so we don't set the definition here, so we don't confuse user programs
 * that don't know about our special restrictions.
#define _POSIX_THREAD_ATTR_STACKADDR
*/
int pthread_attr_setstackaddr (pthread_attr_t *attr, void *  stackaddr);
int pthread_attr_getstackaddr (pthread_attr_t *attr, void ** stackaddr);

#define _POSIX_THREAD_ATTR_STACKSIZE
#define PTHREAD_MIN_STACK 0x1000
int pthread_attr_setstacksize (pthread_attr_t *attr, size_t  stacksize);
int pthread_attr_getstacksize (pthread_attr_t *attr, size_t *stacksize);

/* XSH5/Unix 98 functions not in posix spec */
int pthread_attr_getguardsize (pthread_attr_t *attr, size_t *guardsize);
int pthread_attr_setguardsize (pthread_attr_t *attr, size_t  guardsize);

int _pthread_setstackspacing    (size_t spacing, size_t guardsize);
int _pthread_check_stackattr    (pthread_attr_t *attr);
int _pthread_set_stack_defaults (pthread_attr_t *attr);
void _pthread_stack_init	(void);

#define GUARDSIZE       (4*PAGE_SIZE)
#define STACK_SIZE  (2 * 1024 * 1024)
#define GET_TLS_FROM_STACK(sp) ((pthread_descr)(((unsigned long)(sp) | (_stackspacing-1))+1) - 1)
#define STACK_START (unsigned int)(USRSTACK - MAXSSIZ)
#define THREAD_STACK_START_ADDRESS ((char *)((STACK_START-_stackspacing) & ~(_stackspacing - 1)))

#ifndef COMPILING_STACK_C
extern int _stackspacing;
extern int _defaultguardsize;
extern int _tlspagesize;
extern caddr_t _thread_stack_start;
#endif

#endif
