/*
 * copyright Douglas Santry 1996
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the above copyright is retained
 * in the source form.
 *
 * THIS SOFTWARE IS PROVIDED BY Douglas Santry AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE  
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE   
 * ARE DISCLAIMED.  IN NO EVENT SHALL Douglas Santry OR CONTRIBUTORS BE LIABLE 
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL   
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS      
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF  
 * SUCH DAMAGE.    
 *
 * Significant mods by John S. Dyson.  No additional copyright restrictions
 * imposed due to changes by John Dyson.
 *
 * Vastly stripped to only one function by Richard Seaman, Jr., and slightly
 * modified as well.
 */


#include <errno.h>
#include "pthread.h"

int _stackspacing;
int _defaultguardsize;
int _tlspagesize;
caddr_t _thread_stack_start;

#define COMPILING_STACK_C
#include "internals.h"

/*
 * Allows the parent to set the max stack size (and spacing).
 * This can only be called once, and before any threads are created.
 */
int
_pthread_setstackspacing(size_t spacing, size_t guardsize)
{
	size_t bit;
	
	if (_stackspacing)
		return EACCES ;

	spacing = (spacing + (PAGE_SIZE - 1)) & ~(PAGE_SIZE - 1);
	guardsize = (guardsize + (PAGE_SIZE - 1)) & ~(PAGE_SIZE - 1);
	_tlspagesize = sizeof (struct _pthread_descr_struct); 
	_tlspagesize = (_tlspagesize + (PAGE_SIZE - 1)) & ~(PAGE_SIZE - 1);
	if (spacing < PTHREAD_MIN_STACK + guardsize + _tlspagesize)
		return (EINVAL);

	bit = 1;
	while (bit < spacing) {
		bit <<= 1;
	}

	_stackspacing = bit;
	_defaultguardsize = guardsize;
	_thread_stack_start = (caddr_t)(STACK_START & ~(_stackspacing - 1)) - _stackspacing;
	return 0;
}

